

## Running a simulation
N <- 750 ## number of test takers
K <- 20 ## number of items
C <- 4 ## number of response categories
Q <- 2 ## number of latent dimensions
P <- 3 ## number of covariates (including 1s for the intercept)

# generate data
sim <- simdata(N,K,C,Q=2,P)
## check the simulated data
sim$A
sim$B
sim$SigmaP
var(sim$theta)
cor(sim$theta)

## run the model twice
out1 <- MIRTRR(Y=sim$Y,X= sim$X,Q=2,XG=10000)
out2 <- MIRTRR(Y=sim$Y,X= sim$X,Q=2,XG=10000)

## EAP estimates of the residual covariance matrices
colMeans(out1$MSigmaP)
colMeans(out2$MSigmaP)

## obtain SDs of covariance parameters
apply(out1$MSigmaP,2,sd)


## make some traceplots. 
plot(out1$MSigmaP[,1])
plot(out1$MSigmaP[,4])


## Obtain covariate estimates and compare with simulated values
colMeans(out1$MBReg) # EAPs
apply(out1$MBReg,2,sd) # SDs
colMeans(out2$MBReg) # EAPs
sim$B ## simulated values


## Making the traceplots as shown in the paper, with horizontal line depicting the true, simulated value. Just run the code below and the figures will appear. 
trueB <- c(sim$B)[c(2,3,5,6)]
BB <- out1$MBReg[5001:10000,,]
BB1 <- cbind(BB[,2:3,1],BB[,2:3,2])
                           
#BB1 <- cbind(matrix(BB,ncol=1),sort(rep(1:4,1000)))
BB <- out2$MBReg[5001:10000,,]
BB2 <- cbind(BB[,2:3,1],BB[,2:3,2])
#BB2 <- cbind(matrix(BB,ncol=1),sort(rep(1:4,1000)))

#cbind(rep(1:1000,4),BB)
#BB <- data.frame(BB)
#p <- ggplot(BB, aes(x=BB[,1],y=BB[,2]))

y.name <- expression(gamma[11])
par(mfrow=c(2,2))
plot(BB1[,1], type ="l", col = "red", xlab = "Iteration", ylab = y.name)
lines(BB2[,1],col = " blue")            
abline(trueB[1],0, cex = 3)

y.name <- expression(gamma[12])
plot(BB1[,2], type ="l", col = "red", xlab = "Iteration", ylab = y.name)
lines(BB2[,2],col = " blue")            
abline(trueB[2],0)


#par(mfrow=c(2,1))
y.name <- expression(gamma[21])
plot(BB1[,3], type ="l", col = "red", xlab = "Iteration", ylab = y.name)
lines(BB2[,3],col = " blue")            
abline(trueB[3],0)

y.name <- expression(gamma[22])
plot(BB1[,4], type ="l", col = "red", xlab = "Iteration", ylab = y.name)
lines(BB2[,4],col = " blue")            
abline(trueB[4],0)


### Make plots of simulated versus re-estimated ability parameters. 
par(mfrow= c(1,2))
x.name <- expression(theta[1]*-simulated)
y.name <- expression(theta[1]*-EAP)
plot(sim$theta[,1],out1$EAPtheta[,1], xlab = x.name, ylab = y.name)
abline(a=0,b=1,col="red")
                           
x.name <- expression(theta[2]*-simulated)
y.name <- expression(theta[2]*-EAP)
plot(sim$theta[,2],out1$EAPtheta[,2], xlab = x.name, ylab = y.name)
abline(a=0,b=1,col="red")

## Plots of simulated versus re-estimated loadings. 
plot(sim$A[2:20,1],colMeans(out1$MA)[2:20], xlab="simulated loadings dim 1", ylab="EAP loadings dim 1")
abline(0,1)


plot(sim$A[2:20,2],colMeans(out1$MA)[22:40], xlab="simulated loadings dim 2", ylab="EAP loadings dim 2")
abline(0,1)


## Some convergence checks using the coda package. 
library("coda")
BB1 <- as.mcmc(BB1)
BB2 <- as.mcmc(BB2)

gelman.diag(list(BB1,BB2))
gelman.plot(list(BB1,BB2))
densityplot(BB1)
